@@ -4,7 +4,7 @@ sys.path.append(os.path.abspath(os.path.join(os.path.dirname(__file__), '../../'
 
 import uuid
 
-from src.autoagents_graph import NL2Workflow
+from src.autoagents_graph import NL2Workflow, DifyConfig
 from src.autoagents_graph.engine.dify import DifyStartState, DifyLLMState, DifyEndState, START, END
 
 
@@ -18,8 +18,12 @@ def main():
     # 创建Dify平台工作流
     workflow = NL2Workflow(
         platform="dify",
-        app_name="Multi-CoT Ensemble工作流",
-        app_description="基于aflow框架的多轮思维链集成工作流"
+        config=DifyConfig(
+            app_name="Multi-CoT Ensemble工作流",
+            app_description="基于aflow框架的多轮思维链集成工作流",
+            app_icon="🤖",
+            app_icon_background="#FFEAD5"
+        )
     )
 
     # 添加开始节点
