@@ -1,10 +1,5 @@
 from typing import List
-from ..models.graph_types import (
-    QuestionInputState, AiChatState, ConfirmReplyState, 
-    KnowledgeSearchState, Pdf2MdState, AddMemoryVariableState,
-    InfoClassState, CodeFragmentState, ForEachState, HttpInvokeState,
-    OfficeWordExportState,MarkdownToWordState,CodeExtractorState,DatabaseQueryState
-)
+from ..models.graph_types import NODE_STATE_FACTORY
 
 
 class AgentifyParser:
@@ -49,8 +44,8 @@ class AgentifyParser:
                         custom_inputs[key] = value
             return custom_inputs
         
-        if module_type in ["codeFragment", "codeExtractor"]:
-            # 特殊处理codeFragment/codeExtractor - 提取代码相关参数
+        if module_type in ["codeFragment", "codeExtract"]:
+            # 特殊处理codeFragment/codeExtract - 提取代码相关参数
             inputs_dict = {}
             outputs_dict = {}
             
@@ -140,7 +135,7 @@ class AgentifyParser:
                 "model", "systemPrompt", "quotePrompt", "temperature", "topP", "maxToken",
                 "text",  # 对于confirmreply的预设文本
                 "items", "index", "item", "length", "loopEnd", "loopStart",  # forEach相关参数
-                "_code_", "language", "description",  # codeFragment/codeExtractor相关参数
+                "_code_", "language", "description",  # codeFragment/codeExtract相关参数
                 "templateFile"  
                 "markdown", "word" , "fileInfo" 
                 "code", "fileInfo" 
@@ -230,8 +225,8 @@ class AgentifyParser:
             "httpInvoke": "http_invoke",
             "officeWordExport": "word_export",
             "markdownToWord": "markdown_to_word",
-            "codeExtractor": "code_extractor",
-            "DatabaseQuery": "database_query",
+            "codeExtract": "code_extract",
+            "databaseQuery": "database_query",
         }
         
         base_name = type_mapping.get(module_type, "node")
@@ -279,7 +274,7 @@ class AgentifyParser:
                 # 更新custom_inputs中的labels为变量引用
                 custom_inputs["labels"] = f"__{labels_var_name}__"  # 特殊标记，稍后替换
         
-        code_lines.append("    graph.add_node(")
+        code_lines.append("    workflow.add_node(")
         
         # 处理START节点的特殊情况
         if module_type == "questionInput" and node_id == "simpleInputId":
@@ -330,44 +325,10 @@ class AgentifyParser:
     @staticmethod
     def _get_state_class_name(module_type: str) -> str:
         """根据module_type获取对应的State类名称字符串"""
-        state_name_mapping = {
-            "questionInput": "QuestionInputState",
-            "aiChat": "AiChatState",
-            "confirmreply": "ConfirmReplyState",
-            "knowledgesSearch": "KnowledgeSearchState",
-            "pdf2md": "Pdf2MdState",
-            "addMemoryVariable": "AddMemoryVariableState",
-            "infoClass": "InfoClassState",
-            "codeFragment": "CodeFragmentState",
-            "forEach": "ForEachState",
-            "httpInvoke": "HttpInvokeState",
-            "officeWordExport": "OfficeWordExportState",
-            "markdownToWord": "MarkdownToWordState",
-            "codeExtractor": "CodeExtractorState",
-            "DatabaseQuery": "DatabaseQueryState",
-        }
-        return state_name_mapping.get(module_type)
-
-    @staticmethod
-    def _get_state_class(module_type: str):
-        """根据module_type获取对应的State类"""
-        state_mapping = {
-            "questionInput": QuestionInputState,
-            "aiChat": AiChatState,
-            "confirmreply": ConfirmReplyState,
-            "knowledgesSearch": KnowledgeSearchState,
-            "pdf2md": Pdf2MdState,
-            "addMemoryVariable": AddMemoryVariableState,
-            "infoClass": InfoClassState,
-            "codeFragment": CodeFragmentState,
-            "forEach": ForEachState,
-            "httpInvoke": HttpInvokeState,
-            "officeWordExport": OfficeWordExportState,
-            "markdownToWord": MarkdownToWordState,
-            "codeExtractor": CodeExtractorState,
-            "DatabaseQuery": DatabaseQueryState,
-        }
-        return state_mapping.get(module_type)
+        state_class = NODE_STATE_FACTORY.get(module_type)
+        if state_class:
+            return state_class.__name__
+        return None
     
     @staticmethod
     def _generate_edge_code(edge: dict, id_mapping: dict = None, nodes: list = None, labels_vars: dict = None) -> str:
@@ -399,9 +360,9 @@ class AgentifyParser:
                     uuid_keys = list(labels_dict.keys())
                     if source_handle in uuid_keys:
                         index = uuid_keys.index(source_handle)
-                        return f'    graph.add_edge({source_formatted}, {target_formatted}, list({labels_var_name}.keys())[{index}], "{target_handle}")'
+                        return f'    workflow.add_edge({source_formatted}, {target_formatted}, list({labels_var_name}.keys())[{index}], "{target_handle}")'
             
-        return f'    graph.add_edge({source_formatted}, {target_formatted}, "{source_handle}", "{target_handle}")'
+        return f'    workflow.add_edge({source_formatted}, {target_formatted}, "{source_handle}", "{target_handle}")'
     
     @staticmethod
     def _is_uuid_format(text: str) -> bool:
@@ -423,13 +384,15 @@ class AgentifyParser:
     def _generate_header_code(self, has_infoclass: bool = False) -> List[str]:
         """生成代码头部（导入和初始化部分）"""
         code_lines = []
-        code_lines.append("from autoagents_graph.agentify import AgentifyGraph, START")
-        code_lines.append("from autoagents_graph.agentify.models import QuestionInputState, AiChatState, ConfirmReplyState, KnowledgeSearchState, Pdf2MdState, AddMemoryVariableState,CodeFragmentState,InfoClassState,ForEachState,OfficeWordExportState,MarkdownToWordState,CodeExtractorState,DatabaseQueryState")
+        code_lines.append("from autoagents_graph import NL2Workflow")
+        code_lines.append("from autoagents_graph.engine.agentify import START")
+        code_lines.append("from autoagents_graph.engine.agentify.models import QuestionInputState, AiChatState, ConfirmReplyState, KnowledgeSearchState, Pdf2MdState, AddMemoryVariableState,CodeFragmentState,InfoClassState,ForEachState,OfficeWordExportState,MarkdownToWordState,CodeExtractState,DatabaseQueryState")
         if has_infoclass:
             code_lines.append("import uuid")
         code_lines.append("")
         code_lines.append("def main():")
-        code_lines.append("    graph = AgentifyGraph(")
+        code_lines.append("    workflow = NL2Workflow(")
+        code_lines.append('        platform="agentify",')
         code_lines.append(f'        personal_auth_key="{self.auth_key}",')
         code_lines.append(f'        personal_auth_secret="{self.auth_secret}",')
         code_lines.append(f'        base_url="{self.base_url}"')
@@ -443,7 +406,7 @@ class AgentifyParser:
         code_lines = []
         code_lines.append("")
         code_lines.append("    # 编译")
-        code_lines.append("    graph.compile(")
+        code_lines.append("    workflow.compile(")
         code_lines.append('        name="从json导出的工作流",')
         code_lines.append('        intro="",')
         code_lines.append('        category="自动生成",')
