@@ -5,15 +5,16 @@ This module contains data models for Dify platform.
 """
 
 from .dify_types import (
-    DifyNode, DifyEdge, DifyConfig, DifyApp, DifyWorkflow,
+    DifyNode, DifyEdge, DifyWorkflowConfig, DifyApp, DifyWorkflow,
     DifyGraph, DifyStartState, DifyLLMState, DifyKnowledgeRetrievalState,
-    DifyEndState, create_dify_node_state
+    DifyEndState, DifyAnswerState, DifyCodeState, DifyToolState, 
+    DifyIfElseState, create_dify_node_state
 )
 
 __all__ = [
     "DifyNode",
     "DifyEdge", 
-    "DifyConfig",
+    "DifyWorkflowConfig",
     "DifyApp",
     "DifyWorkflow",
     "DifyGraph",
@@ -21,6 +22,10 @@ __all__ = [
     "DifyLLMState",
     "DifyKnowledgeRetrievalState",
     "DifyEndState",
+    "DifyAnswerState",
+    "DifyCodeState", 
+    "DifyToolState",
+    "DifyIfElseState",
     "create_dify_node_state",
 ]
 
