@@ -5,10 +5,12 @@ This module contains core services for Dify graph building.
 """
 
 from .dify_graph import DifyGraph, START, END
+from .dify_parser import DifyParser
 
 __all__ = [
     "DifyGraph",
     "START",
     "END",
+    "DifyParser",
 ]
 
