@@ -5,8 +5,11 @@ This module contains high-level services for workflow creation and management.
 """
 
 from .nl2workflow import NL2Workflow
+from .config import AgentifyConfig, DifyConfig
 
 __all__ = [
     "NL2Workflow",
+    "AgentifyConfig",
+    "DifyConfig",
 ]
 
